==> speech-analytic-testing_2.3.1_database.tar.gz: database/mssql/procedures/GetBatchSchedulesSummary.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetBatchSchedulesSummary] (
	@VCC VARCHAR(50) = NULL, 
	@SearchCriteria VARCHAR(50) = NULL,
	@SearchExpression VARCHAR(500) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- BUSCAMOS LAS ULTIMAS EJECUCIONES DE CADA AGENDA
	;WITH CTE_LAST_VALID_EXECUTIONS AS (
		SELECT BSE.[VCC],
				BSE.[BatchScheduleId],
				BSE.[BatchId],
				BSE.[ExecutionDate],
				BSE.[Status],
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] DESC)
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[Status] IN ('CREATED', 'RUNNING')
				AND BSE.[Status] NOT IN ('PENDING', 'REGISTERED_ON_REDIS', 'CANCELLED_BY_NO_INTERACTIONS_FOUND')
				-- AND BSE.[Status] = 'COMPLETED'
	),
	CTE_LAST_EXECUTIONS AS (
		SELECT CTE_VE.[VCC], 
				CTE_VE.[BatchScheduleId], 
				CTE_VE.[BatchId], 
				CASE WHEN CTE_VE.[Status] = 'REGISTERED_ON_REDIS' THEN NULL ELSE CTE_VE.[ExecutionDate] END		'LastExecutionDate', 
				CTE_VE.[Status]
			FROM CTE_LAST_VALID_EXECUTIONS CTE_VE
			WHERE CTE_VE.[RN] = 1
	),
	CTE_NEXT_VALID_EXECUTIONS AS (
		SELECT BSE.[VCC],
				BSE.[BatchScheduleId],
				BSE.[BatchId],
				BSE.[ExecutionDate],
				BSE.[Status],
				CTE_LA.[LastExecutionDate],
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] ASC)
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			INNER JOIN CTE_LAST_EXECUTIONS CTE_LA
				ON CTE_LA.[VCC] = BS.[VCC]
					AND CTE_LA.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BSE.[Status] = 'PENDING'
	),
	CTE_NEXT_EXECUTIONS AS (
		SELECT CTE_VE.[VCC], 
				CTE_VE.[BatchScheduleId], 
				CTE_VE.[BatchId], 
				CTE_VE.[ExecutionDate]																			'NextExecutionDate', 
				CTE_VE.[LastExecutionDate]																		'LastExecutionDate', 
				CTE_VE.[Status]
			FROM CTE_NEXT_VALID_EXECUTIONS CTE_VE
			WHERE CTE_VE.[RN] = 1
	),
	CTE_SUMMARY AS (
		SELECT CTE_NE.*,
				COUNT(BSE.[Id])																					'Total',
				COUNT(IIF(BSE.[STATUS] LIKE 'REGISTERED_%', 1, NULL))											'Preparing',
				COUNT(IIF(BSE.[STATUS] LIKE '%_CREATED' OR BSE.[STATUS] LIKE '%_STARTED', 1, NULL))				'Running',
				COUNT(IIF(BSE.[STATUS] LIKE 'CANCELLED_%', 1, NULL))											'Cancelled',
				COUNT(IIF(BSE.[STATUS] LIKE 'COMPLETED%' OR BSE.[STATUS] = 'FAILED', 1, NULL))					'Finished',
				COUNT(IIF(BSE.[STATUS] = 'COMPLETED', 1, NULL))													'Succeed',
				COUNT(IIF(BSE.[STATUS] LIKE '%_WITH_ERRORS', 1, NULL))											'Error',
				COUNT(IIF(BSE.[STATUS] LIKE '%FAILED%', 1, NULL))												'Failed'
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			INNER JOIN CTE_NEXT_EXECUTIONS CTE_NE 
				ON CTE_NE.[VCC] = BS.[VCC]
					AND CTE_NE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = 'collegeocc'
				AND BS.[Status] IN ('CREATED', 'RUNNING')
				AND BSE.[Status] <> 'PENDING'
			GROUP BY CTE_NE.[VCC], CTE_NE.[BatchScheduleId], CTE_NE.[BatchId], CTE_NE.[NextExecutionDate], CTE_NE.[LastExecutionDate], CTE_NE.[Status]
	)-- select * from CTE_SUMMARY
		SELECT BS.[VCC]																	'vcc',
				BS.[Id]																	'id',
				BS.[BatchType]															'batchType',
				BS.[Frequency]															'frequency',
				--BS.[Weekday]															'weekday',
				--BS.[Monthday]															'monthday',
				BS.[DaysInterval]														'daysInterval',
				BS.[HoursInterval]														'hoursInterval',
				BS.[StartDate]															'startDate',
				BS.[EndDate]															'endDate',
				BS.[FirstExecutionDate]													'firstExecutionDate',
				BS.[Status]																'status',
				--BS.[LastExecutionDate]													'lastExecutionDate',
				-- BS.[FinalExecutionDate]													'finalExecutionDate', 
				ISNULL(CTE_S.[Total], 0)												'total',
				ISNULL(CTE_S.[Preparing], 0)											'preparing',
				ISNULL(CTE_S.[Running], 0)												'running',
				ISNULL(CTE_S.[Cancelled], 0)											'cancelled',
				ISNULL(CTE_S.[Finished], 0)												'finished',
				ISNULL(CTE_S.[Succeed], 0)												'succeed',
				ISNULL(CTE_S.[Error], 0)												'error',
				ISNULL(CTE_S.[Failed], 0)												'failed',
				CTE_S.[LastExecutionDate]												'lastExecutionDate',
				CTE_S.[Status]															'lastExecutionStatus',
				CTE_S.[NextExecutionDate]												'nextExecutionDate',
				BS.[CreatedDate]														'createdDate',
				BS.[CreatedByUserId]													'createdByUserId',
				BS.[LastModifiedDate]													'lastModifiedDate',
				BS.[LastModifiedByUserId]												'lastModifiedByUserId'
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			LEFT JOIN CTE_SUMMARY CTE_S
				ON CTE_S.[VCC] = BS.[VCC]
					AND CTE_S.[BatchScheduleId] = BS.[Id]
			LEFT JOIN [dbo].[Process] P (NOLOCK)
				ON BS.[BatchType] = 'TRANSCRIPTION'
					AND P.[VCC] = CTE_S.[VCC]
					AND P.[Name] = CTE_S.[BatchId]
			LEFT JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON BS.[BatchType] = 'EVALUATION_PLAN'
					AND EP.[Instance] = CTE_S.[VCC]
					AND EP.[ID] = CTE_S.[BatchId]
			WHERE BS.[VCC] = @VCC
				AND ISNULL(BS.[Id], '') LIKE CASE WHEN @SearchCriteria = 'NAME' THEN '%' + @SearchExpression + '%' ELSE '%' END

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_2.4.1_database.tar.gz: database/mssql/procedures/GetBatchSchedulesSummary.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetBatchSchedulesSummary] (
	@VCC VARCHAR(50) = NULL, 
	@SearchCriteria VARCHAR(50) = NULL,
	@SearchExpression VARCHAR(500) = NULL,
	@BatchType VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- CREAMOS UNA TABLA TEMPORAL PARA LA ULTIMA EJECUCION DE CADA AGENDA
	CREATE TABLE #TMP_SCHEDULE_LAST_EXECUTION (
		[VCC] VARCHAR(50),
		[BatchScheduleId] VARCHAR(50),
		[BatchId] VARCHAR(50),
		[LastExecutionDate] DATETIME,
		[Status] VARCHAR(50)
	)
	-- BUSCAMOS LAS ULTIMAS EJECUCIONES DE CADA AGENDA
	;WITH CTE_LAST_VALID_EXECUTIONS AS (
		SELECT BSE.[VCC],
				BSE.[BatchScheduleId],
				BSE.[BatchId],
				BSE.[ExecutionDate],
				BSE.[Status],
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] DESC)
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[BatchType] = @BatchType
				AND BS.[Status] IN ('CREATED', 'RUNNING', 'PAUSED', 'FINISHED')
				AND BSE.[Status] NOT IN ('PENDING', 'REGISTERED_ON_REDIS', 'READY_TO_EXECUTE', 'CANCELLED_BY_NO_INTERACTIONS_FOUND')
	)
	INSERT INTO #TMP_SCHEDULE_LAST_EXECUTION
		SELECT [VCC],
				[BatchScheduleId],
				[BatchId],
				[ExecutionDate],
				[Status]
			FROM CTE_LAST_VALID_EXECUTIONS 
			WHERE RN = 1

			--SELECT * FROM [dbo].[BatchScheduleExecution] (NOLOCK) WHERE [BatchScheduleId] = '20211030_0141_prueba'

	-- CREAMOS UNA TABLA TEMPORAL PARA LA PROXIMA EJECUCION DE CADA AGENDA
	CREATE TABLE #TMP_SCHEDULE_NEXT_EXECUTION (
		VCC VARCHAR(50),
		BatchScheduleId VARCHAR(50),
		NextExecutionDate DATETIME
	)
	-- BUSCAMOS LAS ULTIMAS EJECUCIONES DE CADA AGENDA
	;WITH CTE_NEXT_EXECUTIONS AS (
		SELECT BSE.[VCC],
				BSE.[BatchScheduleId],
				BSE.[BatchId],
				BSE.[ExecutionDate],
				BSE.[Status],
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] ASC)
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[BatchType] = @BatchType
				AND BSE.[Status] IN ('PENDING', 'REGISTERED_ON_REDIS')
	)
	INSERT INTO #TMP_SCHEDULE_NEXT_EXECUTION
		SELECT [VCC],
				[BatchScheduleId],
				[ExecutionDate]
			FROM CTE_NEXT_EXECUTIONS 
			WHERE RN = 1



	-- BUSCAMOS LOS RESUMENES DE LAS EJECUCIONES
	;WITH CTE_SUMMARY AS (
		SELECT BS.[VCC], 
				BS.[Id]																							'BatchScheduleId',	
				COUNT(BSE.[Id])																					'Total',
				COUNT(IIF(BSE.[STATUS] LIKE 'REGISTERED_%', 1, NULL))											'Preparing',
				COUNT(IIF(BSE.[STATUS] LIKE '%_CREATED' OR BSE.[STATUS] LIKE '%_STARTED', 1, NULL))				'Running',
				COUNT(IIF(BSE.[STATUS] LIKE 'CANCELLED_%', 1, NULL))											'Cancelled',
				COUNT(IIF(BSE.[STATUS] LIKE 'COMPLETED%' OR BSE.[STATUS] = 'FAILED', 1, NULL))					'Finished',
				COUNT(IIF(BSE.[STATUS] = 'COMPLETED', 1, NULL))													'Succeed',
				COUNT(IIF(BSE.[STATUS] LIKE '%_WITH_ERRORS', 1, NULL))											'Error',
				COUNT(IIF(BSE.[STATUS] LIKE '%FAILED%', 1, NULL))												'Failed'
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			LEFT JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[BatchType] = @BatchType
				AND BS.[Status] IN ('CREATED', 'RUNNING', 'PAUSED', 'FINISHED')
				AND BSE.[Status] <> 'PENDING'
			GROUP BY BS.[VCC], BS.[Id]
	)
		SELECT BS.[VCC]																	'vcc',
				BS.[Id]																	'id',
				BS.[BatchType]															'batchType',
				BS.[Frequency]															'frequency',
				--BS.[Weekday]															'weekday',
				--BS.[Monthday]															'monthday',
				BS.[DaysInterval]														'daysInterval',
				BS.[HoursInterval]														'hoursInterval',
				BS.[StartDate]															'startDate',
				BS.[EndDate]															'endDate',
				BS.[FirstExecutionDate]													'firstExecutionDate',
				BS.[Status]																'status',
				--BS.[LastExecutionDate]													'lastExecutionDate',
				-- BS.[FinalExecutionDate]													'finalExecutionDate', 
				ISNULL(CTE_S.[Total], 0)												'total',
				ISNULL(CTE_S.[Preparing], 0)											'preparing',
				ISNULL(CTE_S.[Running], 0)												'running',
				ISNULL(CTE_S.[Cancelled], 0)											'cancelled',
				ISNULL(CTE_S.[Finished], 0)												'finished',
				ISNULL(CTE_S.[Succeed], 0)												'succeed',
				ISNULL(CTE_S.[Error], 0)												'error',
				ISNULL(CTE_S.[Failed], 0)												'failed',
				TMP_LE.[LastExecutionDate]												'lastExecutionDate',
				TMP_LE.[Status]															'lastExecutionStatus',
				TMP_NE.[NextExecutionDate]												'nextExecutionDate',
				BS.[CreatedDate]														'createdDate',
				BS.[CreatedByUserId]													'createdByUserId',
				BS.[LastModifiedDate]													'lastModifiedDate',
				BS.[LastModifiedByUserId]												'lastModifiedByUserId'
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			LEFT JOIN CTE_SUMMARY CTE_S
				ON CTE_S.[VCC] = BS.[VCC]
					AND CTE_S.[BatchScheduleId] = BS.[Id]
			LEFT JOIN #TMP_SCHEDULE_LAST_EXECUTION TMP_LE 
				ON TMP_LE.[VCC] = BS.[VCC]
					AND TMP_LE.[BatchScheduleId] = BS.[Id]
			LEFT JOIN #TMP_SCHEDULE_NEXT_EXECUTION TMP_NE 
				ON TMP_NE.[VCC] = BS.[VCC]
					AND TMP_NE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[BatchType] = @BatchType
				AND ISNULL(BS.[Id], '') LIKE CASE WHEN @SearchCriteria = 'NAME' THEN '%' + @SearchExpression + '%' ELSE '%' END

	-- ELIMINAMOS LAS TABLAS TEMPORALES
	IF OBJECT_ID('tempdb..#TMP_SCHEDULE_LAST_EXECUTION') IS NOT NULL DROP TABLE #TMP_SCHEDULE_LAST_EXECUTION
	IF OBJECT_ID('tempdb..#TMP_SCHEDULE_NEXT_EXECUTION') IS NOT NULL DROP TABLE #TMP_SCHEDULE_NEXT_EXECUTION
		
	

	/*
	-- BUSCAMOS LAS ULTIMAS EJECUCIONES DE CADA AGENDA
	;WITH CTE_LAST_VALID_EXECUTIONS AS (
		SELECT BSE.[VCC],
				BSE.[BatchScheduleId],
				BSE.[BatchId],
				BSE.[ExecutionDate],
				BSE.[Status],
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] DESC)
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[Status] IN ('CREATED', 'RUNNING', 'PAUSED')
				AND BSE.[Status] NOT IN ('PENDING', 'REGISTERED_ON_REDIS', 'CANCELLED_BY_NO_INTERACTIONS_FOUND')
				-- AND BSE.[Status] = 'COMPLETED'
	),
	CTE_LAST_EXECUTIONS AS (
		SELECT CTE_VE.[VCC], 
				CTE_VE.[BatchScheduleId], 
				CTE_VE.[BatchId], 
				CASE WHEN CTE_VE.[Status] = 'REGISTERED_ON_REDIS' THEN NULL ELSE CTE_VE.[ExecutionDate] END		'LastExecutionDate', 
				CTE_VE.[Status]
			FROM CTE_LAST_VALID_EXECUTIONS CTE_VE
			WHERE CTE_VE.[RN] = 1
	),
	CTE_NEXT_VALID_EXECUTIONS AS (
		SELECT BSE.[VCC],
				BSE.[BatchScheduleId],
				BSE.[BatchId],
				BSE.[ExecutionDate],
				BSE.[Status],
				CTE_LA.[LastExecutionDate],
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] ASC)
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			INNER JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			INNER JOIN CTE_LAST_EXECUTIONS CTE_LA
				ON CTE_LA.[VCC] = BS.[VCC]
					AND CTE_LA.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BSE.[Status] = 'PENDING'
	),
	CTE_NEXT_EXECUTIONS AS (
		SELECT CTE_VE.[VCC], 
				CTE_VE.[BatchScheduleId], 
				CTE_VE.[BatchId], 
				CTE_VE.[ExecutionDate]																			'NextExecutionDate', 
				CTE_VE.[LastExecutionDate]																		'LastExecutionDate', 
				CTE_VE.[Status]
			FROM CTE_NEXT_VALID_EXECUTIONS CTE_VE
			WHERE CTE_VE.[RN] = 1
	),
	CTE_SUMMARY AS (
		SELECT BS.[VCC], 
				BS.[Id]																							'BatchScheduleId',	
				CTE_NE.[BatchId], 
				CTE_NE.[NextExecutionDate], 
				CTE_NE.[LastExecutionDate], 
				CTE_NE.[Status],
				COUNT(BSE.[Id])																					'Total',
				COUNT(IIF(BSE.[STATUS] LIKE 'REGISTERED_%', 1, NULL))											'Preparing',
				COUNT(IIF(BSE.[STATUS] LIKE '%_CREATED' OR BSE.[STATUS] LIKE '%_STARTED', 1, NULL))				'Running',
				COUNT(IIF(BSE.[STATUS] LIKE 'CANCELLED_%', 1, NULL))											'Cancelled',
				COUNT(IIF(BSE.[STATUS] LIKE 'COMPLETED%' OR BSE.[STATUS] = 'FAILED', 1, NULL))					'Finished',
				COUNT(IIF(BSE.[STATUS] = 'COMPLETED', 1, NULL))													'Succeed',
				COUNT(IIF(BSE.[STATUS] LIKE '%_WITH_ERRORS', 1, NULL))											'Error',
				COUNT(IIF(BSE.[STATUS] LIKE '%FAILED%', 1, NULL))												'Failed'
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			LEFT JOIN [dbo].[BatchScheduleExecution] BSE (NOLOCK)
				ON BSE.[VCC] = BS.[VCC]
					AND BSE.[BatchScheduleId] = BS.[Id]
			LEFT JOIN CTE_NEXT_EXECUTIONS CTE_NE 
				ON CTE_NE.[VCC] = BS.[VCC]
					AND CTE_NE.[BatchScheduleId] = BS.[Id]
			WHERE BS.[VCC] = @VCC
				AND BS.[Status] IN ('CREATED', 'RUNNING', 'PAUSED')
				AND BSE.[Status] <> 'PENDING'
			GROUP BY BS.[VCC], BS.[Id], CTE_NE.[BatchId], CTE_NE.[NextExecutionDate], CTE_NE.[LastExecutionDate], CTE_NE.[Status]
	)-- select * from CTE_SUMMARY
		SELECT BS.[VCC]																	'vcc',
				BS.[Id]																	'id',
				BS.[BatchType]															'batchType',
				BS.[Frequency]															'frequency',
				--BS.[Weekday]															'weekday',
				--BS.[Monthday]															'monthday',
				BS.[DaysInterval]														'daysInterval',
				BS.[HoursInterval]														'hoursInterval',
				BS.[StartDate]															'startDate',
				BS.[EndDate]															'endDate',
				BS.[FirstExecutionDate]													'firstExecutionDate',
				BS.[Status]																'status',
				--BS.[LastExecutionDate]													'lastExecutionDate',
				-- BS.[FinalExecutionDate]													'finalExecutionDate', 
				ISNULL(CTE_S.[Total], 0)												'total',
				ISNULL(CTE_S.[Preparing], 0)											'preparing',
				ISNULL(CTE_S.[Running], 0)												'running',
				ISNULL(CTE_S.[Cancelled], 0)											'cancelled',
				ISNULL(CTE_S.[Finished], 0)												'finished',
				ISNULL(CTE_S.[Succeed], 0)												'succeed',
				ISNULL(CTE_S.[Error], 0)												'error',
				ISNULL(CTE_S.[Failed], 0)												'failed',
				CTE_S.[LastExecutionDate]												'lastExecutionDate',
				CTE_S.[Status]															'lastExecutionStatus',
				CTE_S.[NextExecutionDate]												'nextExecutionDate',
				BS.[CreatedDate]														'createdDate',
				BS.[CreatedByUserId]													'createdByUserId',
				BS.[LastModifiedDate]													'lastModifiedDate',
				BS.[LastModifiedByUserId]												'lastModifiedByUserId'
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			LEFT JOIN CTE_SUMMARY CTE_S
				ON CTE_S.[VCC] = BS.[VCC]
					AND CTE_S.[BatchScheduleId] = BS.[Id]
			LEFT JOIN [dbo].[Process] P (NOLOCK)
				ON BS.[BatchType] = 'TRANSCRIPTION'
					AND P.[VCC] = CTE_S.[VCC]
					AND P.[Name] = CTE_S.[BatchId]
			LEFT JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON BS.[BatchType] = 'EVALUATION_PLAN'
					AND EP.[Instance] = CTE_S.[VCC]
					AND EP.[ID] = CTE_S.[BatchId]
			WHERE BS.[VCC] = @VCC
				AND ISNULL(BS.[Id], '') LIKE CASE WHEN @SearchCriteria = 'NAME' THEN '%' + @SearchExpression + '%' ELSE '%' END
	*/

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
